@@ -33,7 +33,7 @@
 #' @examples
 #' library(dplyr)
 #' # If you want to split by any non-alphanumeric value (the default):
-#' df <- data.frame(x = c(NA, "a.b", "a.d", "b.c"))
+#' df <- data.frame(x = c(NA, "x.y", "x.z", "y.z"))
 #' df %>% separate(x, c("A", "B"))
 #'
 #' # If you just want the second variable:
@@ -41,7 +41,7 @@
 #'
 #' # If every row doesn't split into the same number of pieces, use
 #' # the extra and fill arguments to control what happens:
-#' df <- data.frame(x = c("a", "a b", "a b c", NA))
+#' df <- data.frame(x = c("x", "x y", "x y z", NA))
 #' df %>% separate(x, c("a", "b"))
 #' # The same behaviour as previous, but drops the c without warnings:
 #' df %>% separate(x, c("a", "b"), extra = "drop", fill = "right")
@@ -55,11 +55,11 @@
 #' df %>% separate(x, c("key", "value"), ": ", extra = "merge")
 #'
 #' # Use regular expressions to separate on multiple characters:
-#' df <- data.frame(x = c(NA, "a?b", "a.d", "b:c"))
+#' df <- data.frame(x = c(NA, "x?y", "x.z", "y:z"))
 #' df %>% separate(x, c("A","B"), sep = "([.?:])")
 #'
 #' # convert = TRUE detects column classes:
-#' df <- data.frame(x = c("a:1", "a:2", "c:4", "d", NA))
+#' df <- data.frame(x = c("x:1", "x:2", "y:4", "z", NA))
 #' df %>% separate(x, c("key","value"), ":") %>% str
 #' df %>% separate(x, c("key","value"), ":", convert = TRUE) %>% str
 separate <- function(data, col, into, sep = "[^[:alnum:]]+", remove = TRUE,
@@ -108,7 +108,7 @@ str_separate <- function(x, into, sep, convert = FALSE, extra = "warn", fill = "
 }
 
 strsep <- function(x, sep) {
-  nchar <- stringi::stri_length(x)
+  nchar <- nchar(x)
   pos <- map(sep, function(i) {
     if (i >= 0) return(i)
     pmax(0, nchar + i)
@@ -116,9 +116,10 @@ strsep <- function(x, sep) {
   pos <- c(list(0), pos, list(nchar))
 
   map(1:(length(pos) - 1), function(i) {
-    stringi::stri_sub(x, pos[[i]] + 1, pos[[i + 1]])
+    substr(x, pos[[i]] + 1, pos[[i + 1]])
   })
 }
+
 str_split_fixed <- function(value, sep, n, extra = "warn", fill = "warn") {
   if (extra == "error") {
     warn(glue(
@@ -132,7 +133,7 @@ str_split_fixed <- function(value, sep, n, extra = "warn", fill = "warn") {
   fill <- arg_match(fill, c("warn", "left", "right"))
 
   n_max <- if (extra == "merge") n else -1L
-  pieces <- stringi::stri_split_regex(value, sep, n_max)
+  pieces <- str_split_n(value, sep, n_max = n_max)
 
   simp <- simplifyPieces(pieces, n, fill == "left")
 
@@ -151,6 +152,27 @@ str_split_fixed <- function(value, sep, n, extra = "warn", fill = "warn") {
   simp$strings
 }
 
+str_split_n <- function(x, pattern, n_max = -1) {
+  if (is.factor(x)) {
+    x <- as.character(x)
+  }
+  m <- gregexpr(pattern, x, perl = TRUE)
+  if (n_max > 0) {
+    m <- lapply(m, function(x) slice_match(x, seq_along(x) < n_max))
+  }
+  regmatches(x, m, invert = TRUE)
+}
+
+slice_match <- function(x, i) {
+  structure(
+    x[i],
+    match.length = attr(x, "match.length")[i],
+    index.type = attr(x, "index.type"),
+    useBytes = attr(x, "useBytes")
+  )
+}
+
+
 list_indices <- function(x, max = 20) {
   if (length(x) > max) {
     x <- c(x[seq_len(max)], "...")
