@@ -1,5 +1,3 @@
-context("complete")
-
 test_that("complete with no variables returns data as is", {
   expect_equal(complete(mtcars), mtcars)
 })
@@ -12,6 +10,8 @@ test_that("basic invocation works", {
 })
 
 test_that("preserves grouping", {
+  local_options(lifecycle_verbosity = "quiet")
+
   df <- tibble(x = 1:2, y = 1:2, z = 3:4) %>% dplyr::group_by(x)
   out <- complete(df, x, y)
   expect_s3_class(out, "grouped_df")
